.. meta::
   :description: Tutorials for getting started with Hydra and hydra-zen.

.. _tutorials:

Tutorials
=========

These tutorials will acquaint you with all of the essential functionality of the 
rAI-toolbox. They require no prior experience with these toolbox, but do expect some
familiarity with PyTorch and common concepts from the field of deep learning. 

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   tutorials/CIFAR10-Adversarial-Perturbations.ipynb
   tutorials/ImageNet-Concept-Probing.ipynb
   tutorials/Building-Workflows.ipynb


.. tip::

   Did you enjoy these tutorials? Consider ⭐ `giving us a start on GitHub <https://github.com/mit-ll-responsible-ai/responsible-ai-toolbox>`_ ⭐ to help others find this project.

These tutorials are meant to only focus on practical steps towards concrete outcomes, 
and thus they do not explain *how* the rAI-toolbox works. To gain a deeper 
understanding of the technical details here, please refer to the 
:ref:`toolbox-reference` and :ref:`toolbox-explanation` sections of our 
documentation.
